==> owncloud-10.2.0.zip: owncloud/apps/files_sharing/l10n/hu_HU.js <==
OC.L10N.register(
    "files_sharing",
    {
    "Server to server sharing is not enabled on this server" : "A kiszolgálók közötti megosztás nincs engedélyezve ezen a kiszolgálón",
    "The mountpoint name contains invalid characters." : "A csatlakozási pont neve érvénytelen karaktereket tartalmaz ",
    "Not allowed to create a federated share with the same user server" : "Nem lehet létrehozni egy egyesített megosztást azonos felhasználóval és szerverrel",
    "Invalid or untrusted SSL certificate" : "Érvénytelen vagy nem megbízható az SSL tanúsítvány",
    "Could not authenticate to remote share, password might be wrong" : "Nem sikerült az azonosítás a távoli megosztáshoz. Lehet, hogy rossz a jelszó.",
    "Storage not valid" : "Tároló nem érvényes",
    "Couldn't add remote share" : "A távoli megosztás nem hozható létre",
    "Shared with you" : "Velem osztották meg",
    "Shared with others" : "Én osztottam meg másokkal",
    "Shared by link" : "Linkkel osztottam meg",
    "Uploading..." : "Feltöltés...",
    "Nothing shared with you yet" : "Nincs még semmi megosztva Önnel",
    "Files and folders others share with you will show up here" : "Mások által megosztott fájlok itt jelennek meg",
    "Nothing shared yet" : "Nincs semmi megosztva",
    "Files and folders you share will show up here" : "Az Ön által megosztott fáljok itt jelennek meg",
    "No shared links" : "Nincs megosztott link",
    "Files and folders you share by link will show up here" : "Link-el megosztott fájljai itt jelennek meg",
    "Do you want to add the remote share {name} from {owner}@{remote}?" : "Használatba kívánja venni a {name} távoli megosztást, amit a {owner}@{remote} címről kapott?",
    "Remote share" : "Távoli megosztás",
    "Remote share password" : "Jelszó a távoli megosztáshoz",
    "Cancel" : "Mégsem",
    "Add remote share" : "Távoli megosztás létrehozása",
    "You can upload into this folder" : "Ebbe a könyvtárba fel tud tölteni",
    "No ownCloud installation (7 or higher) found at {remote}" : "Nem található ownCloud telepítés (7 vagy nagyobb verzió) itt  {remote}",
    "Invalid ownCloud url" : "Érvénytelen ownCloud webcím",
    "Share" : "Megosztás",
    "Shared by" : "Megosztotta Önnel",
    "Sharing" : "Megosztás",
    "A file or folder has been <strong>shared</strong>" : "Fájl vagy könyvtár <strong>megosztása</strong>",
    "A file or folder was shared from <strong>another server</strong>" : "Egy fájl vagy könyvtár meg lett osztva egy <strong>másik szerverről</strong>",
    "A public shared file or folder was <strong>downloaded</strong>" : "Egy nyilvánosan megosztott fáljt vagy könyvtárat <strong>letöltöttek</strong>",
    "You received a new remote share %2$s from %1$s" : "A %2$s távoli megosztás érkezett a %1$s -től",
    "You received a new remote share from %s" : "Új távoli megosztás érkezett a %s -től",
    "%1$s accepted remote share %2$s" : "%1$s elfogadta a távoli megosztást %2$s",
    "%1$s declined remote share %2$s" : "%1$s visszavonta a távoli megosztást %2$s",
    "%1$s unshared %2$s from you" : "%1$s megosztás visszavonva %2$s által",
    "Public shared folder %1$s was downloaded" : "Nyilvánosan megosztott könyvtár %1$s le lett töltve",
    "Public shared file %1$s was downloaded" : "Nyilvánosan megosztott fálj %1$s le lett töltve",
    "You shared %1$s with %2$s" : "%1$s-t megosztottam ővele: %2$s",
    "%2$s shared %1$s with %3$s" : "%2$s megosztotta ezt: %1$s, ővele: %3$s",
    "You shared %1$s with group %2$s" : "%1$s-t megosztottam ezzel a csoporttal: %2$s",
    "%2$s shared %1$s with group %3$s" : "%2$s megosztotta ezt: %1$s, ezzel a csoporttal: %3$s",
    "%2$s shared %1$s via link" : "%2$s megosztotta ezt: %1$s, hivatkozással",
    "You shared %1$s via link" : "Megosztottam link segítségével: %1$s",
    "%2$s shared %1$s with you" : "%2$s megosztotta velem ezt: %1$s",
    "Downloaded via public link" : "Letöltve publikus hivatkozással",
    "Shared with %2$s" : "Megosztva vele: %2$s",
    "Shared with %3$s by %2$s" : "Megosztva vele: %3$s, megosztó: %2$s",
    "Shared with group %2$s" : "Megosztva ezzel a csoporttal: %2$s",
    "Shared with group %3$s by %2$s" : "Megosztva ezzel a csoporttal: %3$s, megosztó: %2$s",
    "Shared via link by %2$s" : "Megosztva hivatkozással: %2$s",
    "Shared via public link" : "Megosztva publikus hivatkozással",
    "Shared by %2$s" : "Megosztó: %2$s",
    "Shares" : "Megosztások",
    "This share is password-protected" : "Ez egy jelszóval védett megosztás",
    "The password is wrong. Try again." : "A megadott jelszó nem megfelelő. Próbálja újra!",
    "Password" : "Jelszó",
    "No entries found in this folder" : "Nincsenek bejegyzések ebben a könyvtárban",
    "Name" : "Név",
    "Share time" : "A megosztás időpontja",
    "Expiration date" : "Lejárati idő",
    "Sorry, this link doesn’t seem to work anymore." : "Sajnos úgy tűnik, ez a link már nem működik.",
    "Reasons might be:" : "Ennek az oka a következő lehet:",
    "the item was removed" : "az állományt időközben eltávolították",
    "the link expired" : "lejárt a link érvényességi ideje",
    "sharing is disabled" : "letiltásra került a megosztás",
    "For more info, please ask the person who sent this link." : "További információért forduljon ahhoz, aki ezt a linket küldte Önnek!",
    "Add to your ownCloud" : "Adjuk hozzá a saját ownCloudunkhoz",
    "Download" : "Letöltés",
    "Download %s" : "%s letöltése",
    "Direct link" : "Közvetlen link",
    "Pending" : "Folyamatban",
    "Accept" : "Elfogadás",
    "Decline" : "Elutasítás",
    "Declined" : "Elutasított",
    "Public link" : "Nyilvános link",
    "Couldn't send mail to following recipient(s): %s " : "Email küldese sikertelen a következő(k)nek: %s"
},
"nplurals=2; plural=(n != 1);");

==> owncloud-10.4.0.zip: owncloud/apps/files_sharing/l10n/hu_HU.js <==
OC.L10N.register(
    "files_sharing",
    {
    "Server to server sharing is not enabled on this server" : "A kiszolgálók közötti megosztás nincs engedélyezve ezen a kiszolgálón",
    "The mountpoint name contains invalid characters." : "A csatlakozási pont neve érvénytelen karaktereket tartalmaz ",
    "Not allowed to create a federated share with the same user server" : "Nem lehet létrehozni egy egyesített megosztást azonos felhasználóval és szerverrel",
    "Invalid or untrusted SSL certificate" : "Érvénytelen vagy nem megbízható az SSL tanúsítvány",
    "Could not authenticate to remote share, password might be wrong" : "Nem sikerült az azonosítás a távoli megosztáshoz. Lehet, hogy rossz a jelszó.",
    "Storage not valid" : "Tároló nem érvényes",
    "Couldn't add remote share" : "A távoli megosztás nem hozható létre",
    "Shared with you" : "Velem osztották meg",
    "Shared with others" : "Én osztottam meg másokkal",
    "Shared by link" : "Linkkel osztottam meg",
    "Uploading..." : "Feltöltés...",
    "Nothing shared with you yet" : "Nincs még semmi megosztva Önnel",
    "Files and folders others share with you will show up here" : "Mások által megosztott fájlok itt jelennek meg",
    "Nothing shared yet" : "Nincs semmi megosztva",
    "Files and folders you share will show up here" : "Az Ön által megosztott fáljok itt jelennek meg",
    "No shared links" : "Nincs megosztott link",
    "Files and folders you share by link will show up here" : "Link-el megosztott fájljai itt jelennek meg",
    "Do you want to add the remote share {name} from {owner}@{remote}?" : "Használatba kívánja venni a {name} távoli megosztást, amit a {owner}@{remote} címről kapott?",
    "Remote share" : "Távoli megosztás",
    "Remote share password" : "Jelszó a távoli megosztáshoz",
    "Cancel" : "Mégsem",
    "Add remote share" : "Távoli megosztás létrehozása",
    "You can upload into this folder" : "Ebbe a könyvtárba fel tud tölteni",
    "No ownCloud installation (7 or higher) found at {remote}" : "Nem található ownCloud telepítés (7 vagy nagyobb verzió) itt  {remote}",
    "Invalid ownCloud url" : "Érvénytelen ownCloud webcím",
    "Share" : "Megosztás",
    "Declined" : "Elutasított",
    "Pending" : "Folyamatban",
    "Shared by" : "Megosztotta Önnel",
    "Sharing" : "Megosztás",
    "A file or folder has been <strong>shared</strong>" : "Fájl vagy könyvtár <strong>megosztása</strong>",
    "A file or folder was shared from <strong>another server</strong>" : "Egy fájl vagy könyvtár meg lett osztva egy <strong>másik szerverről</strong>",
    "A public shared file or folder was <strong>downloaded</strong>" : "Egy nyilvánosan megosztott fáljt vagy könyvtárat <strong>letöltöttek</strong>",
    "You received a new remote share %2$s from %1$s" : "A %2$s távoli megosztás érkezett a %1$s -től",
    "You received a new remote share from %s" : "Új távoli megosztás érkezett a %s -től",
    "%1$s accepted remote share %2$s" : "%1$s elfogadta a távoli megosztást %2$s",
    "%1$s declined remote share %2$s" : "%1$s visszavonta a távoli megosztást %2$s",
    "%1$s unshared %2$s from you" : "%1$s megosztás visszavonva %2$s által",
    "Public shared folder %1$s was downloaded" : "Nyilvánosan megosztott könyvtár %1$s le lett töltve",
    "Public shared file %1$s was downloaded" : "Nyilvánosan megosztott fálj %1$s le lett töltve",
    "You shared %1$s with %2$s" : "%1$s-t megosztottam ővele: %2$s",
    "%2$s shared %1$s with %3$s" : "%2$s megosztotta ezt: %1$s, ővele: %3$s",
    "You shared %1$s with group %2$s" : "%1$s-t megosztottam ezzel a csoporttal: %2$s",
    "%2$s shared %1$s with group %3$s" : "%2$s megosztotta ezt: %1$s, ezzel a csoporttal: %3$s",
    "%2$s shared %1$s via link" : "%2$s megosztotta ezt: %1$s, hivatkozással",
    "You shared %1$s via link" : "Megosztottam link segítségével: %1$s",
    "%2$s shared %1$s with you" : "%2$s megosztotta velem ezt: %1$s",
    "Downloaded via public link" : "Letöltve publikus hivatkozással",
    "Shared with %2$s" : "Megosztva vele: %2$s",
    "Shared with %3$s by %2$s" : "Megosztva vele: %3$s, megosztó: %2$s",
    "Shared with group %2$s" : "Megosztva ezzel a csoporttal: %2$s",
    "Shared with group %3$s by %2$s" : "Megosztva ezzel a csoporttal: %3$s, megosztó: %2$s",
    "Shared via link by %2$s" : "Megosztva hivatkozással: %2$s",
    "Shared via public link" : "Megosztva publikus hivatkozással",
    "Shared by %2$s" : "Megosztó: %2$s",
    "Shares" : "Megosztások",
    "Public link" : "Nyilvános link",
    "Couldn't send mail to following recipient(s): %s " : "Email küldese sikertelen a következő(k)nek: %s",
    "Accept" : "Elfogadás",
    "Decline" : "Elutasítás",
    "This share is password-protected" : "Ez egy jelszóval védett megosztás",
    "The password is wrong. Try again." : "A megadott jelszó nem megfelelő. Próbálja újra!",
    "Password" : "Jelszó",
    "No entries found in this folder" : "Nincsenek bejegyzések ebben a könyvtárban",
    "Name" : "Név",
    "Share time" : "A megosztás időpontja",
    "Expiration date" : "Lejárati idő",
    "Sorry, this link doesn’t seem to work anymore." : "Sajnos úgy tűnik, ez a link már nem működik.",
    "Reasons might be:" : "Ennek az oka a következő lehet:",
    "the item was removed" : "az állományt időközben eltávolították",
    "the link expired" : "lejárt a link érvényességi ideje",
    "sharing is disabled" : "letiltásra került a megosztás",
    "For more info, please ask the person who sent this link." : "További információért forduljon ahhoz, aki ezt a linket küldte Önnek!",
    "Download" : "Letöltés",
    "Download %s" : "%s letöltése",
    "Direct link" : "Közvetlen link"
},
"nplurals=2; plural=(n != 1);");
